/**
 * 
 * g_storage 需要在mui.plusReady中使用。
 * 【使用要求】
 * 所有需要保存在手机上的本地变量，均需使用g_storage中已定义的key值
 * 注：其他接口的缓存数据无需满足该规则，已在tools.js中进行了封装
 * 
 * 【前缀说明】
 * USER_: 用户相关的缓存
 * DEVICE_: 设备相关的缓存
 * 
 */
var g_storage = g_storage || {
	/**
	 * 手机屏幕的宽度
	 */
	DEVICE_CLIENT_WIDTH: 'DEVICE_CLIENT_WIDTH',
	/**
	 * 登录key值
	 */
	DEVICE_LOGIN_KEY: 'DEVICE_LOGIN_KEY',
	/**
	 * 用户id值，字符串 
	 */
	DEVICE_USER_ID: 'DEVICE_USER_ID',
	/*
	 * 医生Id
	 */
	DEVICE_DOCTOR_ID: 'DEVICE_DOCTOR_ID',
	/**
	 * 用户名 ，字符串
	 */
	DEVICE_USER_NAME: 'DEVICE_USER_NAME',
	/**
     * 用户头像地址 ，字符串
     */
    DEVICE_USER_HEAD_URL: 'DEVICE_USER_HEAD_URL',
	/**
	 * 用户密码，字符串
	 */
	DEVICE_USER_PW: 'DEVICE_USER_PW',
	/**
	 * 当前版本新旧识别号，数字
	 */
	DEVICE_VERSION_CODE: 'DEVICE_VERSION_CODE',
	/**
	 * 当前版本号 ，字符串
	 */
	DEVICE_VERSION_NAME: 'DEVICE_VERSION_NAME',
	/**
	 * 新版本新旧识别号，数字
	 */
	DEVICE_NEW_VERSION_CODE: 'DEVICE_NEW_VERSION_CODE',
	/**
	 * 新版本号，字符串
	 */
	DEVICE_NEW_VERSION_NAME: 'DEVICE_NEW_VERSION_NAME',
	/**
	 * 是否已首次登录过。至少进行过一次登录就不算首次登录。boolean
	 * true：是
	 * false：否
	 */
	DEVICE_HAS_FIRST_LOGIN: 'DEVICE_HAS_FIRST_LOGIN',
	
	/**
	 * 关爱首页，title0默认选中的item，值为：title0Card、title0Map
	 */
	DEVICE_DEFAULT_TITLE_ITEM: 'DEVICE_DEFAULT_TITLE_ITEM',
	/**
	 * 帮他人激活伙伙提交实名认证前的缓存
	 * TO-DO 应该考虑加USER_前缀
	 */
	USER_ACTIVATE_INFO_BEFORE_OTHER: 'USER_ACTIVATE_INFO_BEFORE_OTHER',
	/**
	 * 激活自己伙伙的缓存
	 * 格式为json字符串
     * key：phone,name,identityCard
	 */
	USER_ACTIVATE_INFO_MY: 'USER_ACTIVATE_INFO_MY',
	/**
	 * 微信第三方登录授权用户信息
	 * 格式为json字符串
	 */
	WEIXIN_AUTH_USER_INFO:'WEIXIN_AUTH_USER_INFO',
	set: function(key, value) {
		//		console.log('set: '+key+' '+value);

		if(!(typeof value == 'string')) { //传入参数类型判断
			//alert('set方法传入的value值必须为字符串！');
			console.log('set方法传入的value值必须为字符串！');
			return;
		}
		if(key.indexOf('USER_') == 0) { //如果是用户相关的key，则加入ID值
			key = myStorage.getItem(g_storage.DEVICE_USER_ID) + ':' + key;
		}

		myStorage.setItem(key, value);
	},
	get: function(key) {
		//		console.log('get: '+key);

		if(key == null || key == undefined) return null;

		if(key.indexOf('USER_') == 0) { //如果是用户相关的key，则加入ID值
			key = myStorage.getItem(g_storage.DEVICE_USER_ID) + ':' + key;
		}

		return myStorage.getItem(key);
	},
	size: function() {
		return myStorage.getLength();
	},
	remove: function(key) {
		if(key == null || key == undefined) return null;

		if(key.indexOf('USER_') == 0) { //如果是用户相关的key，则加入ID值
			key = myStorage.getItem(g_storage.DEVICE_USER_ID) + ':' + key;
		}

		return myStorage.removeItem(key);
	},
	/**
	 * 清空除了变量名为'DEVICE_'前缀以外的缓存值
	 */
	clear: function() {
		var length = myStorage.getLength();
		if(length > 0) {
			for(var i = 0; i < length; i++) {
				var item = myStorage.getItemByIndex(i);
				if(!item.key.indexOf('DEVICE_') == 0) {
					myStorage.removeItem(item.key);
				}
			}
		}
	},
	/**
	 * 帮他人激活伙伙用到的动态缓存
	 *【使用说明】
	 * 根据phone来动态创建key区分不同人,存储，获取，清空缓存
	 */
	setOtherByPhone: function(phone, value) {
		var key = 'USER_ACTIVATE_INFO_OTHER' + phone;
		g_storage.set(key, value);
	},
	getOtherByPhone: function(phone) {
		var key = 'USER_ACTIVATE_INFO_OTHER' + phone;
		return g_storage.get(key);
	},
	removeOtherByPhone: function(phone) {
		var key = 'USER_ACTIVATE_INFO_OTHER' + phone;
		return g_storage.remove(key);
	},

	TYPE_MY : 0,//自己激活伙伙
	TYPE_NEW_OTHER : 1,// 帮助他人时未提交实名认证
	TYPE_OTHER :2,// 帮助他人时提交了实名认证
	/**
	 * 根据激活伙伙类型取数据
	 * @param {Object} type
	 * @param {Object} activateInfo
	 */
	getActivateStorage: function(type, activateInfo) {
    //    alert("getActivateStorage=type:"+type);
		if(type == TYPE_MY) {
			return g_storage.get(g_storage.USER_ACTIVATE_INFO_MY+g_storage.get(g_storage.DEVICE_USER_NAME));
		} else if(type == TYPE_NEW_OTHER) {
			return g_storage.get(g_storage.USER_ACTIVATE_INFO_BEFORE_OTHER);
		} else if(type == TYPE_OTHER) {
			return g_storage.getOtherByPhone(activateInfo.phone);
		}
		return null;
	},
	/**
	 * 根据激活伙伙类型存数据
	 * @param {Object} type
	 * @param {Object} value
	 * @param {Object} activateInfo  
	 */
	setActivateStorage: function(type, value, activateInfo) {
    //    alert("setActivateStorage=type:"+type+"value:"+value);
		if(type == TYPE_MY) {
			g_storage.set(g_storage.USER_ACTIVATE_INFO_MY+g_storage.get(g_storage.DEVICE_USER_NAME), value);
		} else if(type == TYPE_NEW_OTHER) {
			g_storage.set(g_storage.USER_ACTIVATE_INFO_BEFORE_OTHER, value);
		} else if(type == TYPE_OTHER) {
			g_storage.setOtherByPhone(activateInfo.phone, value);
		}
	},
	/**
	 * 删除激活伙伙缓存
	 * @param {Object} type
	 * @param {Object} activateInfo
	 */
	removeActivateStorage:function(type, activateInfo) {
		if(type == TYPE_MY) {
			return g_storage.remove(g_storage.USER_ACTIVATE_INFO_MY+g_storage.get(g_storage.DEVICE_USER_NAME));
		} else if(type == TYPE_NEW_OTHER) {
			return g_storage.remove(g_storage.USER_ACTIVATE_INFO_BEFORE_OTHER);
		} else if(type == TYPE_OTHER) {
			return g_storage.removeOtherByPhone(activateInfo.phone);
		}
	}
	
}
