/**
 * 常用工具类
 */
var g_utils = g_utils || {

	/**
	 * 验证手机号码有效性
	 * @param {string} mobile 手机号码字符串
	 * @description 此函数用于验证手机号码是否有效
	 * @example 
	 * var isMobileNum = g_utils.validateMobile('13712341234');
	 * @return {Boolean}
	 */
	validateMobile: function(mobile) {
		var reg = /(^0{0,1}1[3|4|5|6|7|8|9][0-9]{9}$)/;
		if(reg.test(mobile)) {
			//alert('手机号正确.');  
			return true;
		} else {
			//mui.toast('手机号格式错误.',{ duration:'2000', type:'div' }) 
			return false;
		}
	},
	/**
	 * 验证电话号码是否正确
	 * @param {Object} tel（可能是固定电话或者手机）
	 */
	validateTel: function(tel) {
		var isPhone = /^([0-9]{3,4})?[0-9]{7,8}$/;
		var isMob = /(^0{0,1}1[3|4|5|6|7|8|9][0-9]{9}$)/;

		if(isMob.test(tel) || isPhone.test(tel)) {
			return true;
		} else {
			return false;
		}
	},
	stringToDate: function(str) {
		if(str.length == 10) str += ' 00:00:00';
		return new Date(Date.parse(str.replace(/-/g, "/")));
	},
	/**
	 * 格式化日期指定格式
	 * @param {Object} time 毫秒
	 * @param {Object} format 如“yyyy年MM月dd日”
	 */
	dateFormat: function(time, format) {
		var t = new Date(time);
		var tf = function(i) {
			return(i < 10 ? '0' : '') + i
		};
		return format.replace(/yyyy|MM|dd|HH|mm|ss/g, function(a) {
			switch(a) {
				case 'yyyy':
					return tf(t.getFullYear());
					break;
				case 'MM':
					return tf(t.getMonth() + 1);
					break;
				case 'mm':
					return tf(t.getMinutes());
					break;
				case 'dd':
					return tf(t.getDate());
					break;
				case 'HH':
					return tf(t.getHours());
					break;
				case 'ss':
					return tf(t.getSeconds());
					break;
			}
		})
	},
	/**
	 * 字段为空判断,在js中if条件为null/undefined/0/NaN/""表达式时，统统被解释为false,此外均为true .
	 * @param {Object} arg1
	 */
	isEmpty: function(arg1) {
		return !arg1 && arg1 !== 0 && typeof arg1 !== "boolean" ? true : false;
	},
	isEmptyObject: function(value) {
		return JSON.stringify(value) == "{}";
	},
	/**
	 * 数组是否为空
	 * @param {Object} value
	 */
	isEmptyArray: function(value) {
		return(Array.isArray(value) && value.length === 0) || (Object.prototype.isPrototypeOf(value) && Object.keys(value).length === 0);
	},
	/*
	 * 对象或数组是否为空
	 */
	isEmptyObjectArray: function(obj) {
		// 检验 undefined 和 null
		if(!obj && obj !== 0 && obj !== '') {　　　　　　　　　　
			return true;
		}
		if(Array.prototype.isPrototypeOf(obj) && obj.length === 0) {
			return true;
		}
		if(Object.prototype.isPrototypeOf(obj) && Object.keys(obj).length === 0) {
			return true;
		}
		return false;
	},
	//格式化日期返回当前日期，格式xxxx-xx-xx
	todayFormat: function() {
		var year, month, day;
		var date = new Date();
		year = date.getFullYear();
		month = date.getMonth() + 1;
		day = date.getDate();
		if(month < 10) {
			month = '0' + month;
		}
		if(day < 10) {
			day = '0' + day;
		}
		return year + '-' + month + '-' + day;
	},
	/**
	 * 格式化背景图片格式，即把url(img.png)改为img.png
	 */
	bgImageUrlFormat: function(url) {
		return url.replace(/^url\(|\)$/g, '');
	},

	/**
	 * 添加节点到兄弟节点
	 * @param {Object} newElement
	 * @param {Object} targetElement
	 */
	insertBrotherNode: function(newElement, targetElement) {
		var parent = targetElement.parentNode;
		if(parent.lastChild == targetElement) {
			// 如果最后的节点是目标元素，则直接添加。因为默认是最后  
			parent.appendChild(newElement);
		} else {
			parent.insertBefore(newElement, targetElement.nextSibling);
			//如果不是，则插入在目标元素的下一个兄弟节点 的前面。也就是目标元素的后面  
		}
	},
	/**
	 * 限制带有中文的输入长度
	 * @param {Object} text 输入文字
	 * @param {Object} begin 开始检测的位数 一般传0
	 * @param {Object} num 限制长度
	 */
	setTextMaxLen: function(text, begin, num) {
		var ascRegexp = /[^\x00-\xFF]/g,
			i = 0;
		while(i < begin)(i++ && text.charAt(i).match(ascRegexp) && begin--);
		i = begin;
		var end = begin + num;
		while(i < end)(i++ && text.charAt(i).match(ascRegexp) && end--);
		return text.substring(begin, end);
	},
	getTextLength: function(text) {
		return text.replace(/[^\x00-\xFF]/g, "aa").length;;
	},
	/**
	 * 计算经纬度之间的距离
	 * approx distance between two points on earth ellipsoid
	 * @param {Object} lng1
	 * @param {Object} lat1
	 * @param {Object} lng2
	 * @param {Object} lat2
	 */
	getFlatternDistance: function(lng1, lat1, lng2, lat2) {
		var EARTH_RADIUS = 6378137.0; //单位M
		var PI = Math.PI;
		lat1 = parseFloat(lat1);
		lng1 = parseFloat(lng1);
		lat2 = parseFloat(lat2);
		lng2 = parseFloat(lng2);

		function getRad(d) {
			return d * PI / 180.0;
		}

		var f = getRad((lat1 + lat2) / 2);
		var g = getRad((lat1 - lat2) / 2);
		var l = getRad((lng1 - lng2) / 2);

		var sg = Math.sin(g);
		var sl = Math.sin(l);
		var sf = Math.sin(f);

		var s, c, w, r, d, h1, h2;
		var a = EARTH_RADIUS;
		var fl = 1 / 298.257;

		sg = sg * sg;
		sl = sl * sl;
		sf = sf * sf;

		s = sg * (1 - sl) + (1 - sf) * sl;
		c = (1 - sg) * (1 - sl) + sf * sl;

		w = Math.atan(Math.sqrt(s / c));
		r = Math.sqrt(s * c) / w;
		d = 2 * w * a;
		h1 = (3 * r - 1) / 2 / c;
		h2 = (3 * r + 1) / 2 / s;

		return d * (1 + fl * (h1 * sf * (1 - sg) - h2 * (1 - sf) * sg));
    },
    /*
     * @description    根据某个字段实现对json数组的排序
     * @param   array  要排序的json数组对象
     * @param   field  排序字段（此参数必须为字符串）
     * @param   reverse 是否倒序（默认为false）
     * @return  array  返回排序后的json数组
     */
    jsonSort: function(array, field, reverse) {
        //数组长度小于2 或 没有指定排序字段 或 不是json格式数据
        if(array.length < 2 || !field || typeof array[0] !== "object") return array;
        //数字类型排序
        if(typeof array[0][field] === "number") {
            array.sort(function(x, y) { return x[field] - y[field]});
        }
        //字符串类型排序
        if(typeof array[0][field] === "string") {
            array.sort(function(x, y) { return x[field].localeCompare(y[field])});
        }
        //倒序
        if(reverse) {
            array.reverse();
        }
        return array;
    },
    isPoneAvailable: function(str) {
        var myreg = /^[1][3,4,5,7,8][0-9]{9}$/;
        if(!myreg.test(str)) {
            return false;
        } else {
            return true;
        }
    }
}
