//扩展Date的format方法     
Date.prototype.format = function (format) {    
	var o = {    
		"M+": this.getMonth() + 1,    
		"d+": this.getDate(),    
		"H+": this.getHours(),    
		"m+": this.getMinutes(),    
		"s+": this.getSeconds(),    
		"q+": Math.floor((this.getMonth() + 3) / 3),    
		"S": this.getMilliseconds()    
	}    
	if (/(y+)/.test(format)) {    
		format = format.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));    
	}    
	for (var k in o) {    
		if (new RegExp("(" + k + ")").test(format)) {    
			format = format.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));    
		}    
	}    
	return format;    
}    

/**     
*转换日期对象为日期字符串     
* @param date 日期对象     
* @param isFull 是否为完整的日期数据,     
*               为true时, 格式如"2000-03-05 01:05:04"     
*               为false时, 格式如 "2000-03-05"     
* @return 符合要求的日期字符串     
*/      
function getSmpFormatDate(date, isFull) {    
	var pattern = "";    
	if (isFull == true || isFull == undefined) {    
		pattern = "yyyy-MM-dd HH:mm:ss";    
	} else {    
		pattern = "yyyy-MM-dd";    
	}    
	return getFormatDate(date, pattern);    
}    
/**     
*转换当前日期对象为日期字符串     
* @param date 日期对象     
* @param isFull 是否为完整的日期数据,     
*               为true时, 格式如"2000-03-05 01:05:04"     
*               为false时, 格式如 "2000-03-05"     
* @return 符合要求的日期字符串     
*/      

function getSmpFormatNowDate(isFull) {    
	return getSmpFormatDate(new Date(), isFull);    
}    
/**     
*转换long值为日期字符串     
* @param l long值     
* @param isFull 是否为完整的日期数据,     
*               为true时, 格式如"2000-03-05 01:05:04"     
*               为false时, 格式如 "2000-03-05"     
* @return 符合要求的日期字符串     
*/      

function getSmpFormatDateByLong(l, isFull) {    
	return getSmpFormatDate(new Date(l), isFull);    
}    
/**     
*转换long值为日期字符串     
* @param l long值     
* @param pattern 格式字符串,例如：yyyy-MM-dd HH:mm:ss     
* @return 符合要求的日期字符串     
*/      

function getFormatDateByLong(l, pattern) {    
	return getFormatDate(new Date(l), pattern);    
}    
/**     
*转换日期对象为日期字符串     
* @param l long值     
* @param pattern 格式字符串,例如：yyyy-MM-dd HH:mm:ss     
* @return 符合要求的日期字符串     
*/      
function getFormatDate(date, pattern) {    
	if (date == undefined) {    
		date = new Date();    
	}    
	if (pattern == undefined) {    
		pattern = "yyyy-MM-dd HH:mm:ss";    
	}    
	return date.format(pattern);    
}    


function formatDate(date, format) {   
	if (!date) return;   
	if (!format) format = "yyyy-MM-dd";   
	switch(typeof date) {   
		case "string":   
			date = new Date(date.replace(/-/, "/"));   
			break;   
		case "number":   
			date = new Date(date);   
			break;   
	}    
	if (!date instanceof Date) return;   
	var dict = {   
		"yyyy": date.getFullYear(),   
		"M": date.getMonth() + 1,   
		"d": date.getDate(),   
		"H": date.getHours(),   
		"m": date.getMinutes(),   
		"s": date.getSeconds(),   
		"MM": ("" + (date.getMonth() + 101)).substr(1),   
		"dd": ("" + (date.getDate() + 100)).substr(1),   
		"HH": ("" + (date.getHours() + 100)).substr(1),   
		"mm": ("" + (date.getMinutes() + 100)).substr(1),   
		"ss": ("" + (date.getSeconds() + 100)).substr(1)   
	};       
	return format.replace(/(yyyy|MM?|dd?|HH?|ss?|mm?)/g, function() {   
		return dict[arguments[0]];   
    });                   
}   

function todayTimeMillis(){
	var now=new Date().getTime();
	var todayStr=getFormatDateByLong(now, "yyyy-MM-dd");
	return new Date(Date.parse((todayStr+' 00:00:00').replace(/-/g,"/"))).getTime(); 
}

function tomorrowTimeMillis(){
	return todayTimeMillis()+86400000;
}

/**
 * 判断是否为闰年
 */
function isLeepYear(year) {
    if (year % 100 == 0) {
        if (year % 400 == 0) {
            return true;
        }
    } else {
        if (year % 4 == 0) {
            return true;
        }
    }
    return false;
}

/**
 * now对应的日期年份是否是今年
 */
function isThisYear(now) {
    var yearStr=getFormatDateByLong(new Date().getTime(), "yyyy");
    var thisYearStartTime=new Date(Date.parse((yearStr+'/01/01 00:00:00').replace(/-/g,"/"))).getTime();  
    var oneYearTime;
    if(isLeepYear(parseInt(yearStr))){  //闰年
        oneYearTime=366*86400000;
    }else{  //非闰年
        oneYearTime=365*86400000;
    }
    if(now>=thisYearStartTime&&now<thisYearStartTime+oneYearTime){
        return true;
    }

    return false;
}

//示例
//var s="2005-12-15 09:41:30";   
//var d=new Date(Date.parse(s.replace(/-/g,"/"))); 
//alert(getSmpFormatDateByLong(d.getTime(), true));    
//alert(new Date("2014-05-20 23:13:15"))  //该方法ie8不支持
//alert(getSmpFormatDate(new Date(1279849429000), true));
//alert(getSmpFormatDate(new Date(1279849429000),false));
//alert(getSmpFormatDateByLong(1279829423000, true));
//alert(getSmpFormatDateByLong(1279829423000,false));
//alert(getFormatDateByLong(1279829423000, "yyyy-MM"));
//alert(getFormatDate(new Date(1279829423000), "yy-MM"));