/**
 * 自定义数字键盘（在rem的环境下使用，若不是需修改css）
 * @arg dom：调用此键盘的对象（使用键盘完成，返回值给这个对象,可为null）
 * @arg  n:需要保留几位小数，如：2
 * @arg opts(可以自己定义的一些参数)
 *
 * 启动方式：例如：
 * new KeyBoard(dom,2,opts);
 * @author BBQ
 */
;
(function(exports) {
	var KeyBoard = function(dom, n, opts) {
		var defaultOpts = {
			title: '目标', //值标题
			unit: '卡路里', //值单位
			isInput: true, //是否是input对象调用
			okCallback: function(backValue) {}, //确定回调
			range: '', //只能类似"0-1000"的形式
		}

		for(i in defaultOpts) {
			if(opts[i] === undefined) {
				opts[i] = defaultOpts[i]
			}
		}

		var body = document.getElementsByTagName('body')[0];
		var DIV_ID = opts && opts.divId || '__w_l_h_v_c_z_e_r_o_divid';
		if(document.getElementById(DIV_ID)) {
			body.removeChild(document.getElementById(DIV_ID));
		}
		var mobile = typeof orientation !== 'undefined';

		//样式
		var cssStr = '<style type="text/css">';
		cssStr += '#background{position: fixed;z-index: -1001;top: 0;right: 0;bottom: 0;left: 0;background-color: rgba(0, 0, 0, .3);font-size:0;}';
		cssStr += '.opacityOut{display:none}';
		cssStr += '.keyBordAnimation{transition:bottom 0.3s;-webkit-transition:bottom 0.3s;}'
		cssStr += '.a-bounceinB{bottom:0;}';
		cssStr += '.a-bounceoutB{bottom:-2.74rem;}';
		cssStr += 'table#keyboard{background-color: white;text-align: center;width: 100%;height: 2.74rem;}';
		cssStr += 'table#keyboard td {border: 1px solid gainsboro;border-right: 0;border-bottom: 0;width: 25%;font-size: .24rem;vertical-align: middle;color: #000000;}';
		cssStr += 'table#keyboard td:last-child {border-right: 1px solid gainsboro;}';
		cssStr += 'table#keyboard .key-icon {width: .23rem;height: .17rem;}';
		cssStr += 'table#keyboard .del_icon {width: .3rem;height: .21rem;}';

		cssStr += 'table#keyboard .confirm-btn {background: #30B486;color: #FFFFFF !important;font-size: .16rem;}';
		cssStr += 'table#keyboard .keyboard-head {text-align: left;height: .48rem !important;}';
		cssStr += 'table#keyboard .keyboard-title {padding-left: .1rem;font-size: .14rem;font-weight: 500;color: #000000;}';
		cssStr += 'table#keyboard .keyboard-value {position: relative;top: .03rem;padding-left: .1rem;font-size: .28rem;line-height: .28rem;font-weight: 500;color: #FC692C;}';
		cssStr += 'table#keyboard .keyboard-unit {padding-left: .05rem;font-size: .12rem;color: #999999;}';
		if(!mobile) {
			cssStr += 'table#keyboard td:hover{background-color:#EEEEEE;} ';
		}

		cssStr += '</style>';

		var numberkeyboard = document.createElement('div');
		numberkeyboard.id = DIV_ID;
		numberkeyboard.style.position = 'fixed';
		numberkeyboard.style.left = '0';
		numberkeyboard.style.right = '0';
		numberkeyboard.style.bottom = '-2.74rem';
		numberkeyboard.style.zIndex = '1000';
		numberkeyboard.style.width = '100%';
		numberkeyboard.style.height = '2.74rem';
		numberkeyboard.style.transform = 'bottom 0.3s;'
		numberkeyboard.style.webkitTransform = 'bottom 0.3s;'
		var rangeTip = "";
		if(opts.range != '') {
			rangeTip = "(范围:" + opts.range + ")";
		}

		var back = '<div id="background">123</div>'
		var tableHtml = '<table id="keyboard" border="0" cellspacing="0" cellpadding="0">' +
			'<tbody>' +
			'<tr>' +
			'<td class="keyboard-head" colspan="4">' +
			'<span class="keyboard-title">' + opts.title + '</span>' +
			'<span class="keyboard-value" id="_input"></span>' +
			'<span class="keyboard-unit">' + opts.unit + '</span>' +
			'<span class="keyboard-unit">' + rangeTip + '</span>' +
			'</td>' +
			'</tr>' +
			'<tr>' +
			'<td>1</td>' +
			'<td>2</td>' +
			'<td>3</td>' +
			'<td rowspan="2" class="keyboard-del" id="del"><img src="../../global/plugins/numberKeyboard/img/del_icon.png" id="delImg" class="del_icon" /></td>' +
			'</tr>' +
			'<tr>' +
			'<td>4</td>' +
			'<td>5</td>' +
			'<td>6</td>' +
			'</tr>' +
			'<tr>' +
			'<td>7</td>' +
			'<td>8</td>' +
			'<td>9</td>' +
			'<td rowspan="2" class="confirm-btn" id="confirm">确定</td>' +
			'</tr>' +
			'<tr>' +
			'<td id="decimal">.</td>' +
			'<td>0</td>' +
			'<td class="keyboard-down" id="down"><img src="../../global/plugins/numberKeyboard/img/key_icon.png" class="key-icon"  id="keyImg"/></td>' +
			'</tr>' +
			'</tbody>' +
			'</table>';
		//添加数字键盘
		numberkeyboard.innerHTML = cssStr + back + tableHtml;

		//控制输入框中的格式
		function clearNoNum(obj) {
			var objValue = obj.innerHTML;
			objValue = objValue.replace(/[^\d.]/g, ""); //清除“数字”和“.”以外的字符
			objValue = objValue.replace(/^\./g, ""); //验证第一个字符是数字而不是.
			objValue = objValue.replace(/\.{2,}/g, "."); //只保留第一个. 清除多余的.
			objValue = objValue.replace(".", "$#$").replace(/\./g, "").replace("$#$", ".");
			if(objValue.indexOf(".") < 0 && objValue != "") { //以上已经过滤，此处控制的是如果没有小数点，首位不能为类似于 01、02的金额
				obj.innerHTML = parseFloat(objValue);
			}
			if(objValue.indexOf(".") >= 0) { //判断是否有小数点
				if(objValue.split(".")[1].length > n) { //控制只能输入小数点后2位
					obj.innerHTML = objValue.substr(0, objValue.length - 1);
				}
			}
		}

		function addEvent(e) {
			var ev = e || window.event;
			var _input = document.getElementById("_input");
			var clickEl = ev.element || ev.target;
			var value = clickEl.textContent || clickEl.innerText;
			var backgroundEl = document.getElementById("background");
			var id = clickEl.id;
			var targetName = clickEl.tagName.toLocaleLowerCase();
			if(targetName === 'td' && id !== "down" && id !== "del" && id !== "confirm") {
				if(_input) {
					var _inputValue = _input.innerHTML;
					if(targetName === 'td' && id === "decimal") {
						if(n <= 0) {
							_input.innerHTML = _inputValue;
						} else {
							_input.innerHTML = _inputValue + value;
							clearNoNum(_input);
						}
					} else {
						_input.innerHTML = _inputValue + value;
						clearNoNum(_input);
					}
				}
			} else if(targetName === 'td' && id == "confirm") {
				var _inputValue = _input.innerHTML;
				_inputValue = _inputValue.replace(/\.$/g, ""); //最后一位不能是'.';
				if(_inputValue != "") {
					if(opts.range != '') {
						var min=parseInt(opts.range.split("-")[0]);
						var max=parseInt(opts.range.split("-")[1]);
						//_inputValue=parseInt(_inputValue);
						if(_inputValue >= min&&_inputValue<=max) {
							if(dom) {
								if(opts.isInput) {
									dom.value = _inputValue;
								} else {
									dom.innerHTML = _inputValue;
								}
							}
							numberkeyboard.style.bottom = '-2.74rem'
							
							backgroundEl.classList.add('opacityOut');
							opts.okCallback(_inputValue);
						} else {
							if(g_mui){
								g_mui.toast("超出设定范围");
							}else{
								Toast("超出设定范围", 3000);
							}
						}
					} else {
						if(dom) {
							if(opts.isInput) {
								dom.value = _inputValue;
							} else {
								dom.innerHTML = _inputValue;
							}
						}
						opts.okCallback(_inputValue);
						numberkeyboard.style.bottom = '-2.74rem'
						backgroundEl.classList.add('opacityOut');
					}
				}

			} else if((targetName === 'td' && id == "down") || (targetName === 'img' && id == "keyImg") || (targetName === 'div' && value === "123")) { //点击隐藏，点击空白
				numberkeyboard.style.bottom = '-2.74rem'
				backgroundEl.classList.add('opacityOut');
			} else if((targetName === 'td' && id == "del") || (targetName === 'img' && id == "delImg")) {
				var _inputValue = _input.innerHTML;
				var num = _inputValue;
				if(num) {
					var newNum = num.substr(0, num.length - 1);
					_input.innerHTML = newNum;
				}
			}
		}

		function Toast(msg, duration) {
			duration = isNaN(duration) ? 3000 : duration;
			var m = document.createElement('div');
			m.innerHTML = msg;
			m.style.cssText = "line-height: 0.17rem;position: fixed; z-index: 9999;bottom: 10%;left: 50%;opacity: 0.8;font-size: .14rem;padding: .15rem .25rem;text-align: center;color: #fff;border-radius: .05rem;background-color: #323232;-webkit-transform: translate(-50%, 0);transform: translate(-50%, 0);";
			document.body.appendChild(m);
			setTimeout(function() {
				var d = 0.5;
				m.style.webkitTransition = '-webkit-transform ' + d + 's ease-in, opacity ' + d + 's ease-in';
				m.style.opacity = '0';
				setTimeout(function() {
					document.body.removeChild(m)
				}, d * 1000);
			}, duration);
		}

		if(mobile) {
			numberkeyboard.ontouchstart = addEvent;
		} else {
			numberkeyboard.onclick = addEvent;
		}

		body.appendChild(numberkeyboard);
		numberkeyboard.style.bottom='0'
	}
	exports.KeyBoard = KeyBoard;

})(window);