/*
 * 用于绘制图表格
 * 参数eChart为div的id
 * dataList为展示数据的列表
 * 该函数应在echart文件引入之后使用
 */

/*
 * 根据REM设置图标在div中的偏移量
 */
function getOffset(offset){
	var clientWidth = document.documentElement.clientWidth;
	var remWidth = clientWidth / 3.75;
	return offset*remWidth;
}
/*
 * 绘制单线图
 * 参数eChartDom为eCharts初始化后的Dom对象
 * xMin，xMax对应x轴的最小最大值，Y轴的大小默认从0开始高度自适应
 * dataList数据列表[[x0,y0],[x1,y1],[x2,y2],[x3,y3],[x4,y4]]
 */
function drawLineChart(eChartDom, xMin,xMax, yMax,dataList) {
	var max;
	var offset = getOffset(0.2);	
	max = Math.floor(yMax/0.8);
	var option = {
		//整体背景
		backgroundColor: '#FFFFFF',
		//图表位置坐上角和右下角的偏移
		grid: {
			x: offset,
			y: 5,
			x2: offset,
			y2: 5,
			borderWidth: 0
		},
		//x轴设置
		xAxis: {
			//坐标轴类型
			type: 'value',
			//坐标值范围
			max: xMax,
			min: xMin,
			//坐标轴轴线样式
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			//坐标轴刻度标签
			axisLabel: {
				show: false
			},
			//坐标轴刻度
			axisTick: {
				show: false
			},
			//坐标分割线
			splitLine: {
				show: false,
			},
		},
		yAxis: {
			type: 'value',
			max: max,
			min: 0,
			axisLabel: {
				show: false
			},
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			axisTick: {
				show: false
			},
			splitLine: {
				show: false,
			},
		},
		//设置图表
		series: [{
			name: 'lineOne',
			//图标类型为线条
			type: 'line',
			//拐点样式
			symbol: 'circle',
			//拐点大小
			symbolSize: '6',
			//拐点样式
			itemStyle: {
				normal: {
					color: '#13C1A1',
				},
			},
			//拐点文字样式
			label: {
				normal: {
					show: true,
					position: 'top',				
					textStyle: {
						fontSize: 10,
						color: '#666666',
					}
				}
			},
			//线条样式
			lineStyle: {
				normal: {
					color: '#13C1A1',
				}
			},
			//线条数据
			data: dataList
		}, ]
	}
	eChartDom.setOption(option);
}
/*
 * 绘制双线图
 * 参数eChartDom为eCharts初始化后的Dom对象
 * xMin，xMax对应x轴的最小最大值，Y轴的大小默认从0开始高度自适应
 * upDataList图形中较高线条数据列表[[x0,y0],[x1,y1],[x2,y2],[x3,y3],[x4,y4]]
 * downDataList图形中较低线条数据列表[[x0,y0],[x1,y1],[x2,y2],[x3,y3],[x4,y4]]
 */
function drawDoubleLineChart(eChartDom, xMin,xMax,yMax, upDataList, downDataList) {
	var max;
	var offset = getOffset(0.2);
	max = Math.floor(yMax/0.8);
	var option = {
		backgroundColor: '#FFFFFF',
		grid: {
			x: offset,
			y: 5,
			x2: offset,
			y2: 5,
			borderWidth: 0
		},
		xAxis: {
			type: 'value',
			max: xMax,
			min: xMin,
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			axisLabel: {
				show: false
			},
			axisTick: {
				show: false
			},
			splitLine: {
				show: false,
			},
		},
		yAxis: {
			type: 'value',
			max: max,
			min: 0,
			axisLabel: {
				show: false
			},
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			axisTick: {
				show: false
			},
			splitLine: {
				show: false,
			},
		},
		series: [{
			name: 'lineOne',
			type: 'line',
			symbol: 'circle',
			symbolSize: '6',
			label: {
				normal: {
					show: true,
					textStyle: {
						fontSize: 10,
						color: '#666666'
					}
				}
			},
			itemStyle: {
				normal: {
					color: '#666666',
				},
			},
			lineStyle: {
				normal: {
					color: '#13C1A1',
				}
			},
			data: upDataList
		}, {
			name: 'lineTwo',
			type: 'line',
			symbol: 'circle',
			symbolSize: '6',
			label: {
				normal: {
					show: true,
					position: 'top',
					textStyle: {
						fontSize: 10,
						color: '#666666'
					}
				}
			},
			itemStyle: {
				normal: {
					color: '#D8D8D8',
				},
			},
			lineStyle: {
				normal: {
					color: '#13C1A1',
				}
			},
			data: downDataList
		}]
	}
	eChartDom.setOption(option);
}
/*
 * 绘制饼图
 * 参数eChartDom为eCharts初始化后的Dom对象
 * dataList类型为JsonArray = [{value:"",name:"",itemStyle: {normal: {color: '#000000'}}},{}]
 * dataList中value为区块的占比或数量，name是区块的名字，style中color用于设置区块颜色
 */
function drawPieChart(eChartDom, dataList) {
	var option = {
		backgroundColor: '#FFFFFF',
		series: [{
			type: 'pie',
			radius: '100%',
			center: ['50%', '50%'],
			legendHoverLink:false,
			hoverAnimation: false,
			label: {
				normal: {
					show: false,
				}
			},
			data: dataList,
		}]
	}
	eChartDom.setOption(option);
}
/*
 * 绘制柱状图
 * 参数eChartDom为eCharts初始化后的Dom对象
 * dataList图形中数据列表[2,3,4,5,6]
 */
function drawBarChart(eChartDom, yMax,dataList) {
	var xAxisData = new Array();
	var max = 0
	max = Math.floor(yMax/0.8);
	var offset = getOffset(0.2);
	var option = {
		backgroundColor: '#FFFFFF',
		grid: {
			x: offset,
			y: 5,
			x2: offset,
			y2: 5,
			borderWidth: 0
		},
		xAxis: {
			type: 'category',
			data: xAxisData,
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			//坐标轴刻度标签
			axisLabel: {
				show: false
			},
			//坐标轴刻度
			axisTick: {
				show: false
			},
			//坐标分割线
			splitLine: {
				show: false,
			},
		},
		yAxis: {
			type: 'value',
			max: max,
			min: 0,
			axisLabel: {
				show: false
			},
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			axisTick: {
				show: false
			},
			splitLine: {
				show: false,
			},
		},
		series: [{
			data: dataList,
			type: 'bar',
			barWidth: '15',
			legendHoverLink:false,
			hoverAnimation:false,
			label: {
				normal: {
					position: 'top',
					show: true,
					textStyle: {
						fontSize: 10,
						color: '#666666'
					}
				}
			},
			itemStyle: {
				normal: {
					color: '#666666',
				},
			},
		}]
	};
	eChartDom.setOption(option);
}
/*
 * 绘制阶梯图
 * 参数eChartDom为eCharts初始化后的Dom对象
 * dataStartList起始值[20,21,19.5]，addDataList对应增量[7,7.5,8]
 */
function drawStairsBarChart(eChartDom,dataStartList,addDataList,max,barWidth) {
	var offset = getOffset(0.2);
	var option = {
		backgroundColor: '#FFFFFF',
		grid: {
			x: offset*2,
			y: '7',
			x2: offset,
			y2: '5',
			borderWidth: 0
		},
		xAxis: {
			type: 'category',
			data: max,
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			//坐标轴刻度标签
			axisLabel: {
				show: false
			},
			//坐标轴刻度
			axisTick: {
				show: false
			},
			//坐标分割线
			splitLine: {
				show: false,
			},
		},
		yAxis: {
			type: 'value',
			max: 35,
			min: 20,
			splitNumber: 1,
			axisLabel: {
				show: true,
				margin: 5,
				showMinLabel: true,
				formatter:function(value, index) {
					// 格式化成月/日，只在第一个刻度显示年份
					var text = ""
					if(index == 0){
						text = "20点\n";
					}else{
						text = "\n次日\n10点";
					}
					return text;
				},
				textStyle:{
					fontSize:10
				}
			},
			axisLine: {
				lineStyle: {
					width: 1,
					color: '#DADADA'
				},
			},
			axisTick: {
				show: false
			},
			splitLine: {
				show: false,
			},
		},
		series: [{
				name: '辅助',
				type: 'bar',
				stack: '总量',
				barWidth: barWidth,
				itemStyle: {
					normal: {
						barBorderColor: 'rgba(0,0,0,0)',
						color: 'rgba(0,0,0,0)'
					}
				},
				data: dataStartList
			},
			{
				name: '收入',
				type: 'bar',
				stack: '总量',
				itemStyle: {
					normal: {
						color: '#6097D8',
					},
				},
				data: addDataList
			},
		]
	}
	eChartDom.setOption(option);
}